@@ -46,7 +46,8 @@
  */
 #define OH_GET_DID(sid, did) \
         do { \
-                if (!(did = oh_get_session_domain(sid))) { \
+                did = oh_get_session_domain(sid); \
+                if (did == SAHPI_UNSPECIFIED_DOMAIN_ID) { \
                         dbg("No domain for session id %d",sid); \
                         return SA_ERR_HPI_INVALID_SESSION; \
                 } \
@@ -78,6 +79,10 @@
                         return SA_ERR_HPI_INVALID_RESOURCE; \
                 } \
                 h = oh_get_handler(*hid); \
+		if (h && !h->hnd) { \
+			oh_release_handler(h); \
+			h = NULL; \
+		} \
         } while (0)
 
 /*
