@@ -1260,60 +1260,6 @@ static const cMarshalType *saHpiResourcePowerStateSetOut[] =
   0
 };
 
-static const cMarshalType *oHpiPluginLoadIn[] =
-{
-  &oHpiTextBufferType, // plugin name
-  0
-};
-
-
-static const cMarshalType *oHpiPluginLoadOut[] =
-{
-  &SaErrorType, // result (SaErrorT)
-  0
-};
-
-static const cMarshalType *oHpiPluginUnloadIn[] =
-{
-  &oHpiTextBufferType, // plugin name
-  0
-};
-
-
-static const cMarshalType *oHpiPluginUnloadOut[] =
-{
-  &SaErrorType, // result (SaErrorT)
-  0
-};
-
-static const cMarshalType *oHpiPluginInfoIn[] =
-{
-  &oHpiTextBufferType, // plugin name
-  0
-};
-
-
-static const cMarshalType *oHpiPluginInfoOut[] =
-{
-  &SaErrorType, // result (SaErrorT)
-  &oHpiPluginInfoType,
-  0
-};
-
-static const cMarshalType *oHpiPluginGetNextIn[] =
-{
-  &oHpiTextBufferType, // plugin name
-  0
-};
-
-static const cMarshalType *oHpiPluginGetNextOut[] =
-{
-  &SaErrorType, // result (SaErrorT)
-  &oHpiTextBufferType, // next plugin name (SaHpiTextBufferT)
-  0
-};
-
-
 static const cMarshalType *oHpiHandlerCreateInitIn[] =
 {
   &SaErrorType, // dummy entry
@@ -1395,6 +1341,32 @@ static const cMarshalType *oHpiHandlerGetNextOut[] =
   0
 };
 
+static const cMarshalType *oHpiHandlerFindIn[] =
+{
+	&SaHpiSessionIdType, // session id
+	&SaHpiResourceIdType, // resource id
+	0
+};
+
+static const cMarshalType *oHpiHandlerFindOut[] =
+{
+	&SaErrorType, // result (SaErrorT)
+	&oHpiHandlerIdType, // handler id
+	0
+};
+
+static const cMarshalType *oHpiHandlerRetryIn[] =
+{
+	&oHpiHandlerIdType, // handler id
+	0
+};
+
+static const cMarshalType *oHpiHandlerRetryOut[] =
+{
+	&SaErrorType, // result (SaErrorT)
+	0
+};
+
 
 static const cMarshalType *oHpiGlobalParamGetIn[] =
 {
@@ -1423,6 +1395,22 @@ static const cMarshalType *oHpiGlobalParamSetOut[] =
 };
 
 
+static const cMarshalType *oHpiInjectEventIn[] =
+{
+  &oHpiHandlerIdType,   // global param
+  &SaHpiEventType,
+  &SaHpiRptEntryType,
+  &SaHpiRdrType,        //TODO....needs to be an arrary...not sure what to do
+  0
+};
+
+static const cMarshalType *oHpiInjectEventOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  0
+};
+
+
 static cHpiMarshal hpi_marshal[] =
 {
   dHpiMarshalEntry( saHpiVersionGet ),
@@ -1504,18 +1492,17 @@ static cHpiMarshal hpi_marshal[] =
   dHpiMarshalEntry( saHpiResourceResetStateSet ),
   dHpiMarshalEntry( saHpiResourcePowerStateGet ),
   dHpiMarshalEntry( saHpiResourcePowerStateSet ),
-  dHpiMarshalEntry( oHpiPluginLoad ),
-  dHpiMarshalEntry( oHpiPluginUnload ),
-  dHpiMarshalEntry( oHpiPluginInfo ),
-  dHpiMarshalEntry( oHpiPluginGetNext ),
   dHpiMarshalEntry( oHpiHandlerCreateInit ),
   dHpiMarshalEntry( oHpiHandlerCreateAddTEntry ),
   dHpiMarshalEntry( oHpiHandlerCreate ),
   dHpiMarshalEntry( oHpiHandlerDestroy ),
   dHpiMarshalEntry( oHpiHandlerInfo ),
   dHpiMarshalEntry( oHpiHandlerGetNext ),
+  dHpiMarshalEntry( oHpiHandlerFind ),
+  dHpiMarshalEntry( oHpiHandlerRetry ),
   dHpiMarshalEntry( oHpiGlobalParamGet ),
   dHpiMarshalEntry( oHpiGlobalParamSet ),
+  dHpiMarshalEntry( oHpiInjectEvent ),
 };
 
 
