@@ -21,6 +21,8 @@
 #include <assert.h>
 #include <stdlib.h>
 
+#include <oHpi.h>
+
 
 // text buffer
 static cMarshalType SaHpiTextBufferDataArray = dArray( SaHpiUint8Type, SAHPI_MAX_TEXT_BUFFER_LENGTH );
@@ -72,7 +74,6 @@ static cMarshalType SaHpiEntityPathElements[] =
 
 cMarshalType SaHpiEntityPathType = dStruct( SaHpiEntityPathT, SaHpiEntityPathElements );
 
-
 // sensors
 static cMarshalType SaHpiSensorInterpretedUnionBufferArray = dArray( SaHpiUint8Type, SAHPI_SENSOR_BUFFER_LENGTH );
 
@@ -787,22 +788,15 @@ static cMarshalType SaHpiEventLogEntryElements[] =
 cMarshalType SaHpiEventLogEntryType = dStruct( SaHpiEventLogEntryT, SaHpiEventLogEntryElements );
 
 
-// plugin info
-static cMarshalType oHpiPluginInfoElements[] =
-{
-  dStructElement( oHpiPluginInfoT, refcount, refcountType ),
-  dStructElementEnd()
-};
-
-cMarshalType oHpiPluginInfoType = dStruct( oHpiPluginInfoT, oHpiPluginInfoElements );
-
-
 // handler info
 static cMarshalType plugin_nameBufferArray = dArray( SaHpiUint8Type, MAX_PLUGIN_NAME_LENGTH );
 
 static cMarshalType oHpiHandlerInfoElements[] =
 {
+  dStructElement( oHpiHandlerInfoT, id, oHpiHandlerIdType),
   dStructElement( oHpiHandlerInfoT, plugin_name, plugin_nameBufferArray ),
+  dStructElement( oHpiHandlerInfoT, entity_root, SaHpiEntityPathType ),
+  dStructElement( oHpiHandlerInfoT, load_failed, SaHpiInt32Type ),
   dStructElementEnd()
 };
 
