@@ -39,7 +39,7 @@ cIpmiDomain::cIpmiDomain()
 {
   cIpmiMcVendorFactory::InitFactory();
 
-  m_did = oh_get_default_domain_id();
+  m_did = 0;
   m_own_domain = false;
 
   for( int i = 0; i < 256; i++ )
@@ -219,7 +219,9 @@ cIpmiDomain::Init( cIpmiCon *con )
 
   stdlog << "max number of outstanding = " << num << ".\n";
   m_con->SetMaxOutstanding( num );
-
+/** Commenting this code block due to the multi-domain
+ ** changes in the infrastructure.
+ ** (Renier Morales 11/21/06)
   if ( m_own_domain == true )
   {
     SaHpiTextBufferT buf = m_domain_tag;
@@ -227,6 +229,7 @@ cIpmiDomain::Init( cIpmiCon *con )
                                             0,
                                             m_insert_timeout, 0, 0);
 
+
     if ( m_did == 0 )
     {
         stdlog << "Failed to get a Domain ID - using default\n";
@@ -234,10 +237,10 @@ cIpmiDomain::Init( cIpmiCon *con )
     }
   }
   else
-  {
+  {*/
     m_insert_timeout = SAHPI_TIMEOUT_IMMEDIATE;
-    m_did = oh_get_default_domain_id();
-  }
+    m_did = 0;
+/*}*/
 
   stdlog << "Domain ID " << m_did << "\n";
 
@@ -771,6 +774,20 @@ cIpmiDomain::VerifyControl( cIpmiControl *c )
   return 0;
 }
 
+cIpmiWatchdog *
+cIpmiDomain::VerifyWatchdog ( cIpmiWatchdog *c )
+{
+  for( int i = 0; i < m_mcs.Num(); i++ )
+     {
+       cIpmiMc *mc = m_mcs[i];
+
+       if ( mc->FindRdr( c ) )
+            return c;
+     }
+
+  return 0;
+}
+
 
 cIpmiInventory *
 cIpmiDomain::VerifyInventory( cIpmiInventory *inv )
@@ -953,14 +970,3 @@ cIpmiDomain::Dump( cIpmiLog &dump ) const
 
   dump.End();
 }
-
-
-bool
-cIpmiDomain::Populate()
-{
-  for( int i = 0; i < m_mcs.Num(); i++ )
-       if ( m_mcs[i]->Populate() == false )
-            return false;
-
-  return true;
-}
