@@ -2,7 +2,7 @@
  * ipmi_mc_vendor.cpp
  *
  * Copyright (c) 2004 by FORCE Computers
- * Copyright (c) 2005 by ESO Technologies.
+ * Copyright (c) 2005-2006 by ESO Technologies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,15 +14,23 @@
  * Authors:
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
  *     Pierre Sangouard  <psangouard@eso-tech.com>
+ *     Andy Cress        <arcress@user.sourceforge.net> 
  */
 
 #include <assert.h>
 
+extern "C" {
+#include "SaHpiAtca.h"
+}
+
 #include "ipmi_mc_vendor.h"
 #include "ipmi_mc_vendor_force.h"
+#include "ipmi_mc_vendor_intel.h"
 #include "ipmi_mc_vendor_fix_sdr.h"
 #include "ipmi_domain.h"
 #include "ipmi_control_fan.h"
+#include "ipmi_control_atca_led.h"
+#include "ipmi_watchdog.h"
 
 
 cIpmiMcVendorFactory *cIpmiMcVendorFactory::m_factory = 0;
@@ -63,6 +71,18 @@ cIpmiMcVendorFactory::InitFactory()
        // Force ShMC specific stuff
        m_factory->Register( new cIpmiMcVendorForceShMc( 0x1011 ) );
        m_factory->Register( new cIpmiMcVendorForceShMc( 0x1080 ) );
+       // Intel BMC specific stuff
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x000C ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x001B ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0022 ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0026 ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0028 ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0100 ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x4311 ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0811 ) );
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0900 ) ); /*HSC*/
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0911 ) ); /*HSC*/
+       m_factory->Register( new cIpmiMcVendorIntelBmc( 0x0A0C ) ); /*HSC*/
 
        // Enabling this code will fix badly formed SDR
        // found on various boards tested with the plugin
@@ -203,6 +223,13 @@ cIpmiMcVendor::ProcessSdr( cIpmiDomain * /*domain*/, cIpmiMc * /*mc*/, cIpmiSdrs
   return true;
 }
 
+bool
+cIpmiMcVendor::ProcessFru( cIpmiInventory * /*inv*/, cIpmiMc * /*mc*/,
+                       unsigned int /*sa*/, SaHpiEntityTypeT /*type*/)
+{
+  return true;
+}
+
 
 bool
 cIpmiMcVendor::CreateRdrs( cIpmiDomain *domain, cIpmiMc *source_mc, cIpmiSdrs *sdrs )
@@ -222,6 +249,9 @@ cIpmiMcVendor::CreateRdrs( cIpmiDomain *domain, cIpmiMc *source_mc, cIpmiSdrs *s
   if ( CreateInvs( domain, source_mc, sdrs ) == false )
        return false;
 
+  if ( CreateWatchdogs( domain, source_mc ) == false )
+       return false;
+
   return true;
 }
 
@@ -830,7 +860,7 @@ cIpmiMcVendor::CreateControls( cIpmiDomain *domain, cIpmiMc *source_mc,
   if ( source_mc == 0 )
        return true;
 
-  if ( domain->IsAtca() )
+  if ( source_mc->IsAtcaBoard() )
      {
        return CreateControlsAtca( domain, source_mc, sdrs );
      }
@@ -839,6 +869,56 @@ cIpmiMcVendor::CreateControls( cIpmiDomain *domain, cIpmiMc *source_mc,
 }
 
 
+bool
+cIpmiMcVendor::CreateWatchdogs( cIpmiDomain *domain, cIpmiMc *mc )
+{
+  cIpmiResource *res;
+
+  for ( int i = 0; i < mc->NumResources(); i++ )
+  {
+      res = mc->GetResource ( i );
+
+      if ( res == 0 )
+          continue;
+
+      stdlog << "CreateWatchdogs: addr " << mc->GetAddress() << " FruId " <<
+                  res->FruId() << "\n";
+
+      if (res->FruId() == 0) 
+      {
+          cIpmiMsg  msg( eIpmiNetfnApp, eIpmiCmdGetWatchdogTimer );
+          cIpmiMsg  rsp;
+
+          if (mc->IsRmsBoard() && 
+              res->EntityPath().GetEntryType(0) != SAHPI_ENT_SYSTEM_BOARD) 
+              continue;
+
+          /* Do an IPMI GetWatchdogTimer command to verify this feature. */
+          msg.m_data_len = 0;
+          SaErrorT rv = res->SendCommand( msg, rsp );
+          if (rv != 0 ||  rsp.m_data[0] != 0) {
+              stdlog << "CreateWatchdogs: IPMI error " << rv << " ccode " <<
+                         rsp.m_data[0] << "\n";
+              continue;
+          }
+
+          /* Everything is valid, create the Watchdog RDR */
+          stdlog << "CreateWatchdogs Resource type " << res->EntityPath().GetEntryType(0) << " instance " << res->EntityPath().GetEntryInstance(0) << "\n";
+        
+          cIpmiRdr *wd = new cIpmiWatchdog::cIpmiWatchdog( mc, SAHPI_DEFAULT_WATCHDOG_NUM, 0 );
+        
+          wd->EntityPath() = res->EntityPath();
+        
+          wd->IdString().SetAscii( "Watchdog", SAHPI_TL_TYPE_TEXT, SAHPI_LANG_ENGLISH );
+        
+          res->AddRdr( wd );
+      }
+  }
+
+  return true;
+}
+
+
 bool
 cIpmiMcVendor::CreateControlsAtca( cIpmiDomain *domain, cIpmiMc *mc, cIpmiSdrs *sdrs )
 {
@@ -851,11 +931,10 @@ cIpmiMcVendor::CreateControlsAtca( cIpmiDomain *domain, cIpmiMc *mc, cIpmiSdrs *
       if ( res == 0 )
           continue;
 
-      stdlog << "CreateControlsAtca Resource type " << res->EntityPath().GetEntryType(0) << " instance " << res->EntityPath().GetEntryInstance(0) << "\n";
-
       if ( res->IsFru() )
       {
-        stdlog << "CreateControlsAtcaFan Resource type " << res->EntityPath().GetEntryType(0) << " instance " << res->EntityPath().GetEntryInstance(0) << " FRU " << res->FruId() << "\n";
+        stdlog << "CreateControlsAtca Resource type " << res->EntityPath().GetEntryType(0) << " instance " << res->EntityPath().GetEntryInstance(0) << " FRU " << res->FruId() << "\n";
+        CreateControlAtcaLed( domain, res, sdrs );
         CreateControlAtcaFan( domain, res, sdrs );
       }
   }
@@ -863,6 +942,95 @@ cIpmiMcVendor::CreateControlsAtca( cIpmiDomain *domain, cIpmiMc *mc, cIpmiSdrs *
   return true;
 }
 
+bool
+cIpmiMcVendor::CreateControlAtcaLed( cIpmiDomain *domain, cIpmiResource *res,
+                                     cIpmiSdrs *sdrs )
+{
+  cIpmiMsg msg( eIpmiNetfnPicmg, eIpmiCmdGetFruLedProperties );
+  msg.m_data[0] = dIpmiPicMgId;
+  msg.m_data[1] = res->FruId();
+  msg.m_data_len = 2;
+
+  cIpmiMsg rsp;
+
+  SaErrorT rv = res->SendCommand( msg, rsp );
+
+  if (    rv != SA_OK
+       || rsp.m_data_len < 4
+       || rsp.m_data[0] != eIpmiCcOk
+       || rsp.m_data[1] != dIpmiPicMgId )
+     {
+       stdlog << "cannot get FRU Led properties !\n";
+       return true;
+     }
+
+  unsigned char num_app_leds = rsp.m_data[3];
+
+  if ( num_app_leds > 0xFB )
+    num_app_leds = 0;
+
+  for (int i = 0; i <= (3+num_app_leds); i++)
+  {
+    if ( ( i <= 3 ) && ( rsp.m_data[2] & (1<<i) ) == 0 )
+            continue;
+
+    cIpmiMsg ledmsg( eIpmiNetfnPicmg, eIpmiCmdGetLedColorCapabilities );
+    ledmsg.m_data[0] = dIpmiPicMgId;
+    ledmsg.m_data[1] = res->FruId();
+    ledmsg.m_data[2] = i;
+    ledmsg.m_data_len = 3;
+
+    cIpmiMsg ledrsp;
+
+    rv = res->SendCommand( ledmsg, ledrsp );
+
+    if (   rv != SA_OK
+        || ledrsp.m_data_len < 5
+        || ledrsp.m_data[0] != eIpmiCcOk
+        || ledrsp.m_data[1] != dIpmiPicMgId )
+    {
+        stdlog << "cannot get Led color capabilities !\n";
+        continue;
+    }
+
+    unsigned char led_color_capabilities = ledrsp.m_data[2] & 0x7E;
+    unsigned char led_default_local_color = ledrsp.m_data[3];
+    unsigned char led_default_override_color = ledrsp.m_data[4];
+
+    ledmsg.m_cmd = eIpmiCmdGetFruLedState;
+
+    rv = res->SendCommand( ledmsg, ledrsp );
+
+    if (   rv != SA_OK
+        || ledrsp.m_data_len < 6
+        || ledrsp.m_data[0] != eIpmiCcOk
+        || ledrsp.m_data[1] != dIpmiPicMgId )
+    {
+        continue;
+    }
+
+    if ( (ledrsp.m_data[2] & 0x01) == 0 )
+        led_default_local_color = 0;
+
+    cIpmiControlAtcaLed *l = new cIpmiControlAtcaLed( res->Mc(), ATCAHPI_CTRL_NUM_BLUE_LED+i,
+                                                      led_color_capabilities,
+                                                      led_default_local_color,
+                                                      led_default_override_color );
+    l->EntityPath() = res->EntityPath();
+
+    char ledname[32];
+    if (i == 0)
+        snprintf (ledname, sizeof(ledname), "Blue LED");
+    else
+        snprintf (ledname, sizeof(ledname), "LED %d", i);
+
+    l->IdString().SetAscii( ledname, SAHPI_TL_TYPE_TEXT, SAHPI_LANG_ENGLISH );
+
+    res->AddRdr( l );
+  }
+
+  return true;
+}
 
 bool
 cIpmiMcVendor::CreateControlAtcaFan( cIpmiDomain *domain, cIpmiResource *res,
@@ -882,7 +1050,7 @@ cIpmiMcVendor::CreateControlAtcaFan( cIpmiDomain *domain, cIpmiResource *res,
        || rsp.m_data[0] != eIpmiCcOk
        || rsp.m_data[1] != dIpmiPicMgId )
      {
-       stdlog << "cannot send get fan speed properties !\n";
+       stdlog << "cannot get fan speed properties !\n";
        return true;
      }
 
@@ -891,19 +1059,18 @@ cIpmiMcVendor::CreateControlAtcaFan( cIpmiDomain *domain, cIpmiResource *res,
   unsigned int def      = rsp.m_data[4];
   bool         auto_adj = rsp.m_data[5] & 0x80;
 
-  cIpmiControlFan *f = new cIpmiControlFan( res->Mc(), res->GetControlNum(),
+  cIpmiControlFan *f = new cIpmiControlFan( res->Mc(), ATCAHPI_CTRL_NUM_FAN_SPEED,
                                             min, max, def,
                                             auto_adj );
   f->EntityPath() = res->EntityPath();
 
-  f->IdString().SetAscii( "ATCA-Fan", SAHPI_TL_TYPE_TEXT, SAHPI_LANG_ENGLISH );
+  f->IdString().SetAscii( "Fan Control", SAHPI_TL_TYPE_TEXT, SAHPI_LANG_ENGLISH );
 
   res->AddRdr( f );
 
   return true;
 }
 
-
 bool
 cIpmiMcVendor::CreateInvs( cIpmiDomain *domain, cIpmiMc *source_mc, cIpmiSdrs *sdrs )
 {
@@ -932,16 +1099,21 @@ cIpmiMcVendor::CreateInv( cIpmiDomain *domain, cIpmiMc *mc, cIpmiSdr *sdr, cIpmi
 {
   unsigned int fru_id;
   unsigned int lun;
+  unsigned int sa = mc->GetAddress();
+  SaHpiEntityTypeT     type;
 
   if ( sdr->m_type == eSdrTypeMcDeviceLocatorRecord )
      {
        fru_id = 0;
        lun    = 0;
+       sa     = sdr->m_data[5];
+       type   = (SaHpiEntityTypeT)sdr->m_data[12];
      }
   else
      {
        fru_id = sdr->m_data[6];
        lun    = (sdr->m_data[7] >> 3) & 3;
+       type     = SAHPI_ENT_UNKNOWN;
      }
 
   cIpmiMc *m = mc;
@@ -963,6 +1135,7 @@ cIpmiMcVendor::CreateInv( cIpmiDomain *domain, cIpmiMc *mc, cIpmiSdr *sdr, cIpmi
        inv->Oem() = sdr->m_data[14];
 
        inv->Resource() = res;
+       ProcessFru(inv, m, sa, type); 
        need_add = true;
      }
 
