@@ -28,7 +28,7 @@ cIpmiResource::cIpmiResource( cIpmiMc *mc, unsigned int fru_id )
   : m_sel( false ), m_mc( mc ), m_fru_id( fru_id ),
     m_is_fru( false ),
     m_hotswap_sensor( 0 ),
-    m_fru_state( eIpmiFruStateNotInstalled ),
+    m_picmg_fru_state( eIpmiFruStateNotInstalled ),
     m_policy_canceled( true ),
     m_oem( 0 ), m_current_control_id( 0 ),
     m_populate( false )
@@ -140,6 +140,10 @@ cIpmiResource::Create( SaHpiRptEntryT &entry )
   entry.ResourceId     = oh_uid_from_entity_path( &entry.ResourceEntity );
 
   entry.ResourceCapabilities = SAHPI_CAPABILITY_RESOURCE;
+
+  if ( m_sel )
+    entry.ResourceCapabilities |= SAHPI_CAPABILITY_EVENT_LOG;
+
   if ( m_is_fru == true )
     {
         entry.ResourceCapabilities |= SAHPI_CAPABILITY_FRU;
@@ -155,12 +159,22 @@ cIpmiResource::Create( SaHpiRptEntryT &entry )
                 info.AuxFirmwareRev   = (SaHpiUint8T)m_mc->AuxFwRevision( 0 );
             }
 
-        // Reset supported on ATCA FRUs - Don't allow it on the active ShMC
-        if ( Domain()->IsAtca()
-            && ( m_mc->GetAddress() != dIpmiBmcSlaveAddr) )
-            {
+        // Reset supported on ATCA FRUs - Don't allow it on fru #0 of the active ShMC
+        if ( m_mc->IsAtcaBoard() )
+           {
+                if (!( (m_mc->GetAddress() == dIpmiBmcSlaveAddr) && (m_fru_id == 0) ))
+                {
+                    entry.ResourceCapabilities |= SAHPI_CAPABILITY_RESET;
+                }
+           }
+        else if ( m_mc->IsRmsBoard() ) { /*Rms enabling - 11/09/06 ARCress */
+            SaHpiEntityTypeT type = cIpmiEntityPath(m_entity_path).GetEntryType(0);
+            if (type == SAHPI_ENT_SYSTEM_BOARD)  {
+               stdlog << "Enabling Reset on RMS type " << type << "\n";
                 entry.ResourceCapabilities |= SAHPI_CAPABILITY_RESET;
-            }
+                entry.ResourceCapabilities |= SAHPI_CAPABILITY_POWER;
+           }
+        }
     }
 
   entry.HotSwapCapabilities = 0;
@@ -172,57 +186,70 @@ cIpmiResource::Create( SaHpiRptEntryT &entry )
 }
 
 
-bool
+void
 cIpmiResource::Destroy()
 {
   SaHpiRptEntryT *rptentry;
   stdlog << "removing resource: " << m_entity_path << ").\n";
 
-  // remove sensors
   while( Num() )
-     {
-       cIpmiRdr *rdr = GetRdr( 0 );
-       RemRdr( rdr );
-       delete rdr;
-     }
-
-  // create remove event
-  oh_event *e = (oh_event *)g_malloc0( sizeof( oh_event ) );
-
-  if ( !e )
-     {
-       stdlog << "out of space !\n";
-       return false;
-     }
-
-  memset( e, 0, sizeof( struct oh_event ) );
-  e->type = OH_ET_RESOURCE_DEL;
+  {
+      cIpmiRdr *rdr = GetRdr( 0 );
+      RemRdr( rdr );
+      delete rdr;
+  }
+  
   rptentry = oh_get_resource_by_id( Domain()->GetHandler()->rptcache, m_resource_id );
   if ( !rptentry )
   {
-      stdlog << "Can't find resource in plugin cache !\n";
-      g_free( e );
-      return false;
+       stdlog << "Can't find resource in plugin cache !\n";
   }
-
-  e->u.res_event.entry = *rptentry;
-  stdlog << "cIpmiResource::Destroy OH_ET_RESOURCE_DEL Event resource " << m_resource_id << "\n";
-  Domain()->AddHpiEvent( e );
-
-  // remove resource from local cache
-  int rv = oh_remove_resource( Domain()->GetHandler()->rptcache, m_resource_id );
-
-  if ( rv != 0 )
+  else
   {
-      stdlog << "Can't remove resource from plugin cache !\n";
-      return false;
-  }
+      // create remove event
+      oh_event *e = (oh_event *)g_malloc0( sizeof( oh_event ) );
+  
+      // remove sensors only if resource is FRU
+      if ( rptentry->ResourceCapabilities & SAHPI_CAPABILITY_FRU )
+      {
+           e->event.EventType = SAHPI_ET_HOTSWAP;
+           if (e->resource.ResourceCapabilities & SAHPI_CAPABILITY_MANAGED_HOTSWAP)
+           {
+               e->event.EventDataUnion.HotSwapEvent.HotSwapState = SAHPI_HS_STATE_NOT_PRESENT;
+               e->event.EventDataUnion.HotSwapEvent.PreviousHotSwapState = SAHPI_HS_STATE_NOT_PRESENT;
+           }
+           else
+           {
+               e->event.EventDataUnion.HotSwapEvent.HotSwapState = SAHPI_HS_STATE_NOT_PRESENT;
+               e->event.EventDataUnion.HotSwapEvent.PreviousHotSwapState = SAHPI_HS_STATE_ACTIVE;
+           }
+      }
+      else
+      {
+           e->event.EventType = SAHPI_ET_RESOURCE;
+           e->event.EventDataUnion.ResourceEvent.ResourceEventType = SAHPI_RESE_RESOURCE_FAILURE;
+           rptentry->ResourceFailed = SAHPI_TRUE;
+      }
+  
+      e->event.Source = rptentry->ResourceId;
+      oh_gettimeofday(&e->event.Timestamp);
+      e->event.Severity = rptentry->ResourceSeverity;
+      e->resource = *rptentry;
+      stdlog << "cIpmiResource::Destroy OH_ET_RESOURCE_DEL Event resource " << m_resource_id << "\n";
+      Domain()->AddHpiEvent( e );
 
+      // remove resource from local cache
+      int rv = oh_remove_resource( Domain()->GetHandler()->rptcache, m_resource_id );
+
+      if ( rv != 0 )
+      {
+          stdlog << "Can't remove resource from plugin cache !\n";
+      }
+  }
+  
   m_mc->RemResource( this );
 
   delete this;
-
-  return true;
 }
 
 
@@ -294,46 +321,6 @@ cIpmiResource::RemRdr( cIpmiRdr *rdr )
 }
 
 
-bool
-cIpmiResource::PopulateSel()
-{
-   // find resource
-  SaHpiRptEntryT *resource = Domain()->FindResource( m_resource_id );
-
-  if ( !resource )
-     {
-       stdlog << "Can't find resource !\n";
-       return false;
-     }
-
-  if ( resource->ResourceCapabilities & SAHPI_CAPABILITY_EVENT_LOG )
-     {
-       stdlog << "EventLog capabilities already set !\n";
-       return false;
-     }
-
-  // update resource
-  resource->ResourceCapabilities |= SAHPI_CAPABILITY_EVENT_LOG;
-
-  struct oh_event *e = (struct oh_event *)g_malloc0( sizeof( struct oh_event ) );
-
-  if ( !e )
-     {
-       stdlog << "out of space !\n";
-       return true;
-     }
-
-  memset( e, 0, sizeof( struct oh_event ) );
-  e->type               = OH_ET_RESOURCE;
-  e->u.res_event.entry = *resource;
-
-  stdlog << "cIpmiInventory::CreateRdr OH_ET_RESOURCE Event resource " << resource->ResourceId << "\n";
-  Domain()->AddHpiEvent( e );
-
-  return true;
-}
-
-
 bool
 cIpmiResource::Populate()
 {
@@ -344,16 +331,7 @@ cIpmiResource::Populate()
 
        struct oh_event *e = (struct oh_event *)g_malloc0( sizeof( struct oh_event ) );
 
-       if ( !e )
-          {
-            stdlog << "out of space !\n";
-            return false;
-          }
-
-       memset( e, 0, sizeof( struct oh_event ) );
-       e->type = OH_ET_RESOURCE;
-
-       if ( Create( e->u.res_event.entry ) == false )
+       if ( Create( e->resource ) == false )
           {
             g_free( e );
             return false;
@@ -361,11 +339,11 @@ cIpmiResource::Populate()
 
        // assign the hpi resource id to ent, so we can find
        // the resource for a given entity
-       m_resource_id = e->u.res_event.entry.ResourceId;
+       m_resource_id = e->resource.ResourceId;
 
        // add the resource to the resource cache
        int rv = oh_add_resource( Domain()->GetHandler()->rptcache,
-                                 &(e->u.res_event.entry), this, 1 );
+                                 &(e->resource), this, 1 );
 
        if ( rv != 0 )
        {
@@ -374,23 +352,59 @@ cIpmiResource::Populate()
             return false;
        }
 
-       stdlog << "cIpmiResource::Populate OH_ET_RESOURCE Event resource " << m_resource_id << "\n";
+       for( int i = 0; i < NumRdr(); i++ )
+       {
+           cIpmiRdr *rdr = GetRdr( i );
+
+           if ( rdr->Populate(&e->rdrs) == false )
+	       return false;
+       }
+
+       // find updated resource in plugin cache
+       SaHpiRptEntryT *resource = oh_get_resource_by_id( Domain()->GetHandler()->rptcache,
+                                                            m_resource_id );
+
+       if (!resource)
+            return false;
+
+       // Update resource in event accordingly
+       memcpy(&e->resource, resource, sizeof (SaHpiRptEntryT));
+
+       if (e->resource.ResourceCapabilities & SAHPI_CAPABILITY_FRU)
+       {
+           e->event.EventType = SAHPI_ET_HOTSWAP;
+
+           if (e->resource.ResourceCapabilities & SAHPI_CAPABILITY_MANAGED_HOTSWAP)
+           {
+               SaHpiHsStateT hpi_state = GetHpiState();
+               e->event.EventDataUnion.HotSwapEvent.HotSwapState = hpi_state;
+               e->event.EventDataUnion.HotSwapEvent.PreviousHotSwapState = hpi_state;
+               stdlog << "cIpmiResource::Populate SAHPI_ET_HOTSWAP Managed FRU Event resource " << m_resource_id << " State " << hpi_state << "\n";
+           }
+           else
+           {
+               e->event.EventDataUnion.HotSwapEvent.HotSwapState = SAHPI_HS_STATE_ACTIVE;
+               e->event.EventDataUnion.HotSwapEvent.PreviousHotSwapState = SAHPI_HS_STATE_ACTIVE;
+               stdlog << "cIpmiResource::Populate SAHPI_ET_HOTSWAP FRU Event resource " << m_resource_id << "\n";
+           }
+       }
+       else
+       {
+           e->event.EventType = SAHPI_ET_RESOURCE;
+           e->event.EventDataUnion.ResourceEvent.ResourceEventType =
+               SAHPI_RESE_RESOURCE_ADDED;
+           stdlog << "cIpmiResource::Populate SAHPI_ET_RESOURCE Event resource " << m_resource_id << "\n";
+       }
+
+       e->event.Source = e->resource.ResourceId;
+       e->event.Severity = e->resource.ResourceSeverity;
+       oh_gettimeofday(&e->event.Timestamp);
+
        Domain()->AddHpiEvent( e );
   
-       if ( m_sel )
-            PopulateSel();
-
        m_populate = true;
      }
 
-  for( int i = 0; i < NumRdr(); i++ )
-     {
-       cIpmiRdr *rdr = GetRdr( i );
-
-       if ( rdr->Populate() == false )
-	    return false;
-     }
-
   return true;
 }
 
@@ -445,3 +459,30 @@ cIpmiResource::Deactivate()
                     << rsp.m_data[0] << " !\n";
     }
 }
+
+SaHpiHsStateT
+cIpmiResource::GetHpiState()
+{
+    cIpmiSensorHotswap *hs = GetHotswapSensor();
+
+    if ( hs == 0 )
+        return SAHPI_HS_STATE_NOT_PRESENT;
+
+    tIpmiFruState picmg_state;
+
+    SaErrorT rv = hs->GetPicmgState( picmg_state );
+
+    if ( rv != SA_OK )
+        return SAHPI_HS_STATE_NOT_PRESENT;
+
+    PicmgFruState() = picmg_state;
+
+    SaHpiHsStateT hpi_state;
+
+    rv = hs->GetHpiState( hpi_state );
+
+    if ( rv != SA_OK )
+        return SAHPI_HS_STATE_NOT_PRESENT;
+
+    return hpi_state;
+}
