@@ -29,7 +29,7 @@ static SaErrorT snmp_bc_parse_threshold_str(gchar *str,
 static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 				   gchar *src,
 				   LogSource2ResourceT *logsrc2res,
-				   unsigned int ovr_flags);
+				   unsigned long long ovr_flags);
 
 static SaErrorT snmp_bc_set_cur_prev_event_states(struct oh_handler_state *handle,
 						  EventMapInfoT *eventmap_info,
@@ -48,7 +48,6 @@ static SaErrorT snmp_bc_map2oem(SaHpiEventT *event,
 static ErrLog2EventInfoT *snmp_bc_findevent4dupstr(gchar *search_str,
 						     ErrLog2EventInfoT *dupstrhash_data,
 						     LogSource2ResourceT *logsrc2res);
-
 /**
  * event2hpi_hash_init:
  * @handle: Pointer to handler's data.
@@ -82,7 +81,6 @@ SaErrorT event2hpi_hash_init(struct oh_handler_state *handle)
 	return(SA_OK);
 }
 
-
 /**
  * free_hash_data:
  * @key
@@ -97,8 +95,6 @@ static void free_hash_data(gpointer key, gpointer value, gpointer user_data)
         g_free(value);
 }
 
-
-
 /**
  * event2hpi_hash_free:
  * @handle: Pointer to handler's data.
@@ -179,9 +175,9 @@ SaErrorT snmp_bc_discover_res_events(struct oh_handler_state *handle,
 	max = SNMP_BC_MAX_RESOURCE_EVENT_ARRAY_SIZE;
 	for (i=0; resinfo->event_array[i].event != NULL && i < max; i++) {
 		/* Normalized and convert event string */
-		normalized_str = oh_derive_string(ep, 0, resinfo->event_array[i].event);
+		normalized_str = oh_derive_string(ep, 0, 16, resinfo->event_array[i].event);
 		if (normalized_str == NULL) {
-			dbg(">>>   Cannot derive %s.", resinfo->event_array[i].event);
+			dbg("Cannot derive %s.", resinfo->event_array[i].event);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		} 
 
@@ -276,7 +272,7 @@ SaErrorT snmp_bc_discover_sensor_events(struct oh_handler_state *handle,
 		
 	for (i=0; sinfo->sensor_info.event_array[i].event != NULL && i < max; i++) {
 		/* Normalized and convert event string */
-		normalized_str = oh_derive_string(ep, 0, sinfo->sensor_info.event_array[i].event);
+		normalized_str = oh_derive_string(ep, 0, 16, sinfo->sensor_info.event_array[i].event);
 		if (normalized_str == NULL) {
 			dbg("Cannot derive %s.", sinfo->sensor_info.event_array[i].event);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
@@ -363,7 +359,7 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 			   LogSource2ResourceT *ret_logsrc2res)
 {
 	sel_entry           log_entry;
-	gchar               *recovery_str, *login_str;
+	gchar               *recovery_str, *login_str, *post_str;
 	gchar               root_str[SNMP_BC_MAX_SEL_ENTRY_LENGTH];
 	gchar               search_str[SNMP_BC_MAX_SEL_ENTRY_LENGTH];
 	EventMapInfoT       *eventmap_info;
@@ -379,6 +375,8 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
         struct snmp_bc_hnd *custom_handle;
 	int dupovrovr;
 	struct oh_event *e;
+	SaHpiHsStateT sav_cur_state;
+	
 
 	if (!handle || !logstr || !event || !ret_logsrc2res) {
 		dbg("Invalid parameter.");
@@ -417,7 +415,8 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 	if (recovery_str && (recovery_str == search_str)) {
 		is_recovery_event = SAHPI_TRUE;
 		memset(search_str, 0, SNMP_BC_MAX_SEL_ENTRY_LENGTH);
-		strncpy(search_str, (log_entry.text + strlen(EVT_RECOVERY)), SNMP_BC_MAX_SEL_ENTRY_LENGTH);
+		strncpy(search_str, (log_entry.text + strlen(EVT_RECOVERY)),
+			SNMP_BC_MAX_SEL_ENTRY_LENGTH - strlen(EVT_RECOVERY));
 	}
 
 	/* Adjust "login" event strings - strip username */
@@ -431,8 +430,36 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 		}
 	}
 
+	/* Adjust "POST" event strings - strip post results */
+	post_str = strstr(log_entry.text, LOG_POST_STRING);
+	if (post_str) {
+		memset(search_str, 0, SNMP_BC_MAX_SEL_ENTRY_LENGTH);
+		strncpy(search_str, log_entry.text, (post_str - log_entry.text));
+		search_str[(post_str - log_entry.text - 1)] = '\0';
+	}
+
+        /* Replace internal double blanks with a single blank */
+	{
+		gchar *double_blanks;
+		double_blanks = strstr(log_entry.text, "  ");
+		if (double_blanks) {
+			gchar *tmp_str;
+			int len;
+			tmp_str = log_entry.text;
+			memset(search_str, 0, SNMP_BC_MAX_SEL_ENTRY_LENGTH);
+			do {
+				strncat(search_str, tmp_str, (double_blanks - tmp_str));
+				tmp_str = double_blanks + 1;
+				len = strlen(tmp_str);
+				double_blanks = strstr(tmp_str, "  ");
+			} while (double_blanks);
+			strncat(search_str, tmp_str, len);
+		}
+	}
+
 	/* Adjust "threshold" event strings */
-	if (strstr(log_entry.text, LOG_THRESHOLD_VALUE_STRING)) {
+	if (strstr(log_entry.text, LOG_THRESHOLD_VALUE_STRING) ||
+	    strstr(log_entry.text, LOG_THRESHOLD_STRING)) {
 		is_threshold_event = SAHPI_TRUE;
 		oh_init_textbuffer(&thresh_read_value);
 		oh_init_textbuffer(&thresh_trigger_value);
@@ -452,12 +479,17 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 		gchar *tmp_str;
 		tmp_str = g_strstrip(g_strdup(search_str));
 		strncpy(search_str, tmp_str, SNMP_BC_MAX_SEL_ENTRY_LENGTH);
+		g_free(tmp_str);
 		if ((search_str == NULL || search_str[0] == '\0')) {
 			dbg("Search string is NULL for log string=%s", log_entry.text);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
 	}
 
+	/* Strip any trailing period */
+	if (search_str[strlen(search_str) - 1] == '.')
+		search_str[strlen(search_str) - 1] = '\0';
+
 	trace("Event search string=%s", search_str);
 
 	/* Set dynamic event fields with default values from the log string.
@@ -492,7 +524,9 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 	if (strhash_data->event_ovr & OVR_EXP ||
 	    strhash_data->event_ovr & OVR_VMM ||
 	    strhash_data->event_ovr & OVR_MM1 ||
-	    strhash_data->event_ovr & OVR_MM2) {
+	    strhash_data->event_ovr & OVR_MM2 ||
+	    strhash_data->event_ovr & OVR_MM_PRIME ||
+	    strhash_data->event_ovr & OVR_MM_STBY) {
 
 		err = snmp_bc_logsrc2rid(handle, log_entry.source, &logsrc2res,
 					 strhash_data->event_ovr);
@@ -537,6 +571,7 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 	eventmap_info = (EventMapInfoT *)g_hash_table_lookup(custom_handle->event2hpi_hash_ptr, 
 							     strhash_data->event);
 	if (!eventmap_info) {
+		
 		if (snmp_bc_map2oem(&working, &log_entry, EVENT_NOT_MAPPED)) {
 			dbg("Cannot map to OEM Event %s.", log_entry.text);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
@@ -544,7 +579,7 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 		goto DONE;
 	}
 
-	/* Set static event data defined during resource discovery */
+	/* Set static event data defined during resource discovery */	
 	working = eventmap_info->hpievent;
 	logsrc2res.ep = eventmap_info->ep;
 	logsrc2res.rid = eventmap_info->hpievent.Source;
@@ -570,7 +605,7 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 		err = snmp_bc_set_cur_prev_event_states(handle, eventmap_info, 
 							&working, is_recovery_event);
 		
-		/* Set optional event threshold triSaHpiRptEntryT *rptgger values */
+		/* Set optional event threshold values */
 		if (is_threshold_event == SAHPI_TRUE) {
 			if (oh_encode_sensorreading(&thresh_read_value,
 						    working.EventDataUnion.SensorEvent.TriggerReading.Type,
@@ -582,7 +617,7 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 			working.EventDataUnion.SensorEvent.OptionalDataPresent =
 				working.EventDataUnion.SensorEvent.OptionalDataPresent |
 				SAHPI_SOD_TRIGGER_READING;
-			
+
 			if (oh_encode_sensorreading(&thresh_trigger_value,
 						    working.EventDataUnion.SensorEvent.TriggerThreshold.Type,
 						    &working.EventDataUnion.SensorEvent.TriggerThreshold)) {
@@ -611,7 +646,13 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 			}
 			snmp_bc_set_cur_prev_event_states(handle, eventmap_info,
 							  &working, is_recovery_event);
+							  
+			if (custom_handle->isFirstDiscovery == SAHPI_FALSE) {
+				/* Call rediscover() here to discover newly installed resource */
+				err = snmp_bc_rediscover(handle, &working, &logsrc2res);
+			}						  
 			
+						
 			goto RESUME_TO_EXIT;
 			// return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
@@ -633,7 +674,7 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
   		 ********************************************************************/
 		if (hs_event_state == resinfo2->cur_state) {
 			working.EventDataUnion.HotSwapEvent.HotSwapState = resinfo2->cur_state;
-			working.EventDataUnion.HotSwapEvent.PreviousHotSwapState = resinfo2->prev_state;
+			working.EventDataUnion.HotSwapEvent.PreviousHotSwapState = resinfo2->cur_state;
 			event_severity = SAHPI_INFORMATIONAL;
 		}
 		else {
@@ -651,16 +692,8 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 					autoevent.EventDataUnion.HotSwapEvent.PreviousHotSwapState =
 						resinfo2->prev_state = resinfo2->cur_state;
 					autoevent.EventDataUnion.HotSwapEvent.HotSwapState =
-						resinfo2->cur_state = hs_event_auto_state;
+						resinfo2->cur_state = hs_event_auto_state;				
 					
-					/* oh_print_event(&autoevent, NULL, 0); */
-					
-					/* Add event to event cache and HPI event queue */
-					err = oh_el_prepend(handle->elcache, &autoevent, NULL, rpt);
-					if (err) {
-						dbg("Cannot add entry to cache. Error=%s.", oh_lookup_error(err));
-						return(err);
-					}
 					if (custom_handle->isFirstDiscovery == SAHPI_FALSE) {
 						err = snmp_bc_add_to_eventq(handle, &autoevent, SAHPI_TRUE);
 						if (err) {
@@ -676,10 +709,8 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 			}
 
 			/* Normal hot swap event transitions */
-			/* FIXME:: SES Check valid state ???? - What not valid - do what ??? */
-			working.EventDataUnion.HotSwapEvent.PreviousHotSwapState =
-				resinfo2->prev_state = resinfo2->cur_state;
 
+			sav_cur_state = resinfo2->cur_state;
 			if (is_recovery_event)
 				working.EventDataUnion.HotSwapEvent.HotSwapState =
 				resinfo2->cur_state = 
@@ -689,6 +720,16 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 				resinfo2->cur_state = 
 				eventmap_info->hpievent.EventDataUnion.HotSwapEvent.HotSwapState;
 			
+			if ( (rpt->ResourceCapabilities & SAHPI_CAPABILITY_MANAGED_HOTSWAP) && 
+							(resinfo2->cur_state == SAHPI_HS_STATE_NOT_PRESENT)){
+				working.EventDataUnion.HotSwapEvent.PreviousHotSwapState = sav_cur_state;
+				resinfo2->prev_state = SAHPI_HS_STATE_EXTRACTION_PENDING;			
+			} else {
+				working.EventDataUnion.HotSwapEvent.PreviousHotSwapState =
+							resinfo2->prev_state = sav_cur_state;
+						
+			}
+			
 			/* Determine severity */
 			if (resinfo2->cur_state == SAHPI_HS_STATE_NOT_PRESENT &&
 			    resinfo2->prev_state != SAHPI_HS_STATE_INACTIVE) {
@@ -697,6 +738,14 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 			else {
 				event_severity = SAHPI_INFORMATIONAL;
 			}
+			
+			/* Call rediscover() here to do cleanup for hotswap-remove event */
+			/* cleanup = removing rpt and rdrs from plugin handle->rptcache  */
+			/* rpt and rdrs will be remove in snmp_bc_add_to_eventq() becasue*/
+			/* the new oh_event requires rpt present, else infrastructure    */
+			/* drops the event.  We have to wait to the very last min to     */
+			/* remove rpt from rptcache.                                     */
+  			/* err = snmp_bc_rediscover(handle, &working, &logsrc2res);      */	
 		}
 	}
 	else {
@@ -708,7 +757,6 @@ SaErrorT snmp_bc_log2event(struct oh_handler_state *handle,
 	 * Check to see if need to mark resource as failed.
 	 **************************************************/
 
-	/* FIXME:: SES this is garbage */
 RESUME_TO_EXIT:
 	if (eventmap_info->event_res_failure) {
 		SaHpiRptEntryT *rpt = oh_get_resource_by_id(handle->rptcache, event->Source);
@@ -717,15 +765,21 @@ RESUME_TO_EXIT:
 			if (rpt->ResourceFailed == SAHPI_FALSE) {
 				rpt->ResourceFailed = SAHPI_TRUE;
 				/* Add changed resource to event queue */
-				e = g_malloc0(sizeof(struct oh_event));
+				e = snmp_bc_alloc_oh_event();
 				if (e == NULL) {
 					dbg("Out of memory.");
 					return(SA_ERR_HPI_OUT_OF_SPACE);
 				}
-				e->did = oh_get_default_domain_id();						
-				e->type = OH_ET_RESOURCE;
-				e->u.res_event.entry = *rpt;
-				handle->eventq = g_slist_append(handle->eventq, e);
+				
+				e->resource = *rpt;
+				e->event.Severity = e->resource.ResourceSeverity;
+				e->event.Source =   e->resource.ResourceId;
+				e->event.EventType = SAHPI_ET_RESOURCE;
+				e->event.EventDataUnion.ResourceEvent.ResourceEventType 
+									= SAHPI_RESE_RESOURCE_FAILURE;
+				if (oh_gettimeofday(&e->event.Timestamp) != SA_OK)
+		                		    e->event.Timestamp = SAHPI_TIME_UNSPECIFIED;
+				custom_handle->eventq = g_slist_append(custom_handle->eventq, e);
 			}
 		}
 	}
@@ -735,7 +789,7 @@ RESUME_TO_EXIT:
 	working.Timestamp = event_time;
 	working.Severity = event_severity;
 	memcpy((void *)event, (void *)&working, sizeof(SaHpiEventT));
-	memcpy(ret_logsrc2res, &logsrc2res, sizeof(LogSource2ResourceT));
+	memcpy(ret_logsrc2res, &logsrc2res, sizeof(LogSource2ResourceT));	
 
 	return(SA_OK);
 }
@@ -750,9 +804,9 @@ RESUME_TO_EXIT:
  * information. A NULL is returned if the information cannot be found.
  * 
  * There are several identical Error Log messages strings that are shared by
- * multiple resources. The off-line scripts that populate errlog2event_hash
+ * multiple resources. The scripts that populate errlog2event_hash
  * create unique entries for these duplicate strings by tacking on
- * an unique string (HPIDUP_STRING + duplicate number) to the error log message.
+ * an unique string (HPIDUP_duplicate_number) to the error log message.
  * This is then stored in errlog2event_hash. So there is a unique mapping
  * for each resource with a duplicate string.
  * 
@@ -790,10 +844,10 @@ static ErrLog2EventInfoT *snmp_bc_findevent4dupstr(gchar *search_str,
 		/* Search entire sensor array for the duplicate string's event */
 		for (i=0; (logsrc2res->sensor_array_ptr + i)->sensor.Num != 0; i++) {
 			for (j=0; (logsrc2res->sensor_array_ptr + i)->sensor_info.event_array[j].event != NULL; j++) {
-				normalized_event = oh_derive_string(&(logsrc2res->ep), 0,
+				normalized_event = oh_derive_string(&(logsrc2res->ep), 0, 16,
 						   (logsrc2res->sensor_array_ptr + i)->sensor_info.event_array[j].event);
 				
-				if (!strcmp(dupstr_hash_data->event, normalized_event)) {
+				if (!g_ascii_strcasecmp(dupstr_hash_data->event, normalized_event)) {
 					g_free(normalized_event);
 					return(dupstr_hash_data);
 				}
@@ -803,9 +857,9 @@ static ErrLog2EventInfoT *snmp_bc_findevent4dupstr(gchar *search_str,
 		
 		/* Search resource array for the duplicate string's event */
 		for (i=0; snmp_bc_rpt_array[logsrc2res->rpt].res_info.event_array[i].event != NULL; i++) {
-			normalized_event = oh_derive_string(&(logsrc2res->ep), 0,
+			normalized_event = oh_derive_string(&(logsrc2res->ep), 0, 16,
 					   snmp_bc_rpt_array[logsrc2res->rpt].res_info.event_array[i].event);
-			if (!strcmp(dupstr_hash_data->event, normalized_event)) {
+			if (!g_ascii_strcasecmp(dupstr_hash_data->event, normalized_event)) {
 				g_free(normalized_event);
 				return(dupstr_hash_data);
 			}
@@ -871,9 +925,16 @@ static SaErrorT snmp_bc_parse_threshold_str(gchar *str,
 	thresh_substrs = NULL;
 	err = SA_OK;
 	
-	event_substrs = g_strsplit(str, LOG_READ_VALUE_STRING, -1);
-	thresh_substrs = g_strsplit(event_substrs[1], LOG_THRESHOLD_VALUE_STRING, -1);
-
+	/* Handle BladeCenter's two basic threshold event formats */
+	if (strstr(str, LOG_READ_VALUE_STRING)) {
+		event_substrs = g_strsplit(str, LOG_READ_VALUE_STRING, -1);
+		thresh_substrs = g_strsplit(event_substrs[1], LOG_THRESHOLD_VALUE_STRING, -1);
+	}
+	else {
+		event_substrs = g_strsplit(str, LOG_READ_STRING, -1);
+		thresh_substrs = g_strsplit(event_substrs[1], LOG_THRESHOLD_STRING, -1);
+	}
+   
 	if (thresh_substrs == NULL ||
 	    (thresh_substrs[0] == NULL || thresh_substrs[0][0] == '\0') ||
 	    (thresh_substrs[1] == NULL || thresh_substrs[1][0] == '\0') ||
@@ -898,11 +959,11 @@ static SaErrorT snmp_bc_parse_threshold_str(gchar *str,
 	/* Change any leading period to a blank.
            This put here because MM code added a period after the 
            Threadhold Value string and before the threshold value 
-           (e.g. "Threshold value." 23.0 */
+           (e.g. "Threshold value. 23.0") */
 	if (thresh_substrs[0][0] == '.') thresh_substrs[0][0] = ' ';
 	if (thresh_substrs[1][0] == '.') thresh_substrs[1][0] = ' ';
 
-	/* Strip any leading/trailing blanks - do again after any period conversion */
+	/* Strip any leading/trailing blanks - in case of leading period */
 	thresh_substrs[0] = g_strstrip(thresh_substrs[0]);
 	thresh_substrs[1] = g_strstrip(thresh_substrs[1]);
 	if ((event_substrs[0] == NULL || event_substrs[0] == '\0') ||
@@ -913,10 +974,16 @@ static SaErrorT snmp_bc_parse_threshold_str(gchar *str,
 		goto CLEANUP;
 	}
 
-	/* Strip any ending periods */
-	if (thresh_substrs[0][strlen(thresh_substrs[0]) - 1] == '.')
+	/* Strip any ending periods, commas, colons, or semicolons */
+	if ((thresh_substrs[0][strlen(thresh_substrs[0]) - 1] == '.') ||
+	    (thresh_substrs[0][strlen(thresh_substrs[0]) - 1] == ',') ||
+	    (thresh_substrs[0][strlen(thresh_substrs[0]) - 1] == ':') ||
+	    (thresh_substrs[0][strlen(thresh_substrs[0]) - 1] == ';'))
 		thresh_substrs[0][strlen(thresh_substrs[0]) - 1] = '\0';
-	if (thresh_substrs[1][strlen(thresh_substrs[1]) - 1]  == '.')
+	if ((thresh_substrs[1][strlen(thresh_substrs[1]) - 1]  == '.') ||
+	    (thresh_substrs[1][strlen(thresh_substrs[1]) - 1]  == ',') ||
+	    (thresh_substrs[1][strlen(thresh_substrs[1]) - 1]  == ':') ||
+	    (thresh_substrs[1][strlen(thresh_substrs[1]) - 1]  == ';'))
 		thresh_substrs[1][strlen(thresh_substrs[1]) - 1] = '\0';
 
 	/* Check for valid length */
@@ -927,7 +994,7 @@ static SaErrorT snmp_bc_parse_threshold_str(gchar *str,
 		goto CLEANUP;
 	}
 
-	trace("Threshold strings: %s; %s", thresh_substrs[0], thresh_substrs[1]);
+	trace("Threshold strings: %s and %s", thresh_substrs[0], thresh_substrs[1]);
 	
 	strcpy(root_str, event_substrs[0]);
 	oh_append_textbuffer(read_value_str, thresh_substrs[0]);
@@ -1132,12 +1199,12 @@ static SaErrorT snmp_bc_set_cur_prev_event_states(struct oh_handler_state *handl
 #if 0
 		{       /* Debug section */
 			SaHpiTextBufferT buffer;
-			
+
 			dbg("Event for Sensor=%s", rdr->IdString.Data);
 			oh_decode_eventstate(prev_state, event->EventDataUnion.SensorEvent.EventCategory, &buffer);
 			dbg("  Previous Event State: %s.", buffer.Data);
 			oh_decode_eventstate(cur_state, event->EventDataUnion.SensorEvent.EventCategory, &buffer);
-			dbg("  Current Event State: %s\n", buffer.Data);
+			dbg("  Current Event State: %s", buffer.Data);
 		}
 #endif
 		
@@ -1161,7 +1228,7 @@ static SaErrorT snmp_bc_set_cur_prev_event_states(struct oh_handler_state *handl
 			/* this resource either did not exist at HPI time 0, or    */
 			/* has previously been removed from system.                */
 			/* It is safe to assume that it is being Hotswap-Installed */
-			dbg("No resource data. RID=%x", event->Source);
+			trace("No resource data. RID=%x", event->Source);
 			event->EventDataUnion.HotSwapEvent.PreviousHotSwapState	= SAHPI_HS_STATE_NOT_PRESENT;
 			event->EventDataUnion.HotSwapEvent.HotSwapState =  SAHPI_HS_STATE_INACTIVE;			
 			return(SA_OK);
@@ -1249,10 +1316,12 @@ static SaErrorT snmp_bc_map2oem(SaHpiEventT *event,
  *
  * @ovr_flags is used to indicate exception cases. The two case
  * supported are:
- *   - OVR_EXP    - indicates resource is an expansion card.
- *   - OVR_VMM    - indicates resource is Virtual MM
- *   - OVR_MM1    - indicates resource is the MM 1 card.
- *   - OVR_MM2    - indicates resource is the MM 2 card.
+ *   - OVR_EXP      - indicates resource is an expansion card.
+ *   - OVR_VMM      - indicates resource is Virtual MM
+ *   - OVR_MM1      - indicates resource is the MM 1 card.
+ *   - OVR_MM2      - indicates resource is the MM 2 card.
+ *   - OVR_MM_PRIME - indicates resource is the physical MM of primary MM.
+ *   - OVR_MM_STBY  - indicates resource is the physical MM of the standby MM.
  *
  * Return values:
  * SA_OK - Normal case.
@@ -1261,13 +1330,13 @@ static SaErrorT snmp_bc_map2oem(SaHpiEventT *event,
 static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 				   gchar *src,
 				   LogSource2ResourceT *logsrc2res,
-				   unsigned int ovr_flags)
+				   unsigned long long ovr_flags)
 {
 	int rpt_index;
-	guint loc;
+	guint src_loc;
 	gchar **src_parts, *endptr, *root_tuple;
 	SaErrorT err;
-	SaHpiBoolT isblade, isexpansioncard, isswitch;
+	SaHpiBoolT isblade, isexpansioncard, isswitch, ismm;
 	SaHpiEntityPathT ep, ep_root;
 	SaHpiEntityTypeT entity_type;
 	struct snmp_bc_sensor *array_ptr;
@@ -1277,7 +1346,7 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 		dbg("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
-		
+
 	src_parts = NULL;
 	endptr = NULL;
 	
@@ -1294,7 +1363,7 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
         oh_encode_entitypath(root_tuple, &ep_root);
         
         /* Assume chassis location/type unless another resource type is discovered */
-	loc = ep_root.Entry[0].EntityLocation;
+	src_loc = ep_root.Entry[0].EntityLocation;
 	entity_type = ep_root.Entry[0].EntityType;
 
 	/* Break down "Source" text string to find source's RPT index and location */
@@ -1306,19 +1375,19 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 	}
 
 	/* See if resource is something other than the chassis */
-	isblade = isexpansioncard = isswitch = SAHPI_FALSE;
-	if (!strcmp(src_parts[0], "BLADE")) { 
+	isblade = isexpansioncard = isswitch = ismm = SAHPI_FALSE;
+	if (!g_ascii_strncasecmp(src_parts[0], "BLADE", sizeof("BLADE"))) { 
 		/* All expansion card events are reported as blade events in the Error Log */
 		if (ovr_flags & OVR_EXP) { isexpansioncard = SAHPI_TRUE; }
 		else { isblade = SAHPI_TRUE; }
 	}
 	else {
-		if (!strcmp(src_parts[0], "SWITCH")) { isswitch = SAHPI_TRUE; }
+		if (!g_ascii_strncasecmp(src_parts[0], "SWITCH", sizeof("SWITCH"))) { isswitch = SAHPI_TRUE; }
 	}
 
-	/* If not the chassis, find the location value from last part of log's source string */
+	/* Find the location value from last part of log's source string */
 	if (isexpansioncard == SAHPI_TRUE || isblade == SAHPI_TRUE || isswitch == SAHPI_TRUE) {
-		loc = strtoul(src_parts[1], &endptr, 10);
+		if (src_parts[1]) src_loc = strtoul(src_parts[1], &endptr, 10);
 		if (isexpansioncard == SAHPI_TRUE) {
 			rpt_index = BC_RPT_ENTRY_BLADE_EXPANSION_CARD;
 			array_ptr = &snmp_bc_bem_sensors[0];	
@@ -1338,22 +1407,42 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 	else {
 		/* Check for OVR_MMx overrides, if cannot find explict resource from error
                    logs "Source" field */
-
-		if (ovr_flags & OVR_VMM || ovr_flags & OVR_MM1 || ovr_flags & OVR_MM2) {
+		if (ovr_flags & OVR_VMM || 
+		    ovr_flags & OVR_MM1 || ovr_flags & OVR_MM2 || 
+		    ovr_flags & OVR_MM_PRIME || ovr_flags & OVR_MM_STBY) {
 			if (ovr_flags & OVR_VMM) {
 				rpt_index = BC_RPT_ENTRY_VIRTUAL_MGMNT_MODULE; 
-				loc  = 0;
+				src_loc = 0;
 				array_ptr = &snmp_bc_virtual_mgmnt_sensors[0];
 			}
 			else {
+				ismm = SAHPI_TRUE;
 				rpt_index = BC_RPT_ENTRY_MGMNT_MODULE;
-				if (ovr_flags & OVR_MM1) { loc = 1; }
-				else { loc = 2; }
 				array_ptr = &snmp_bc_mgmnt_sensors[0];
+				
+				if (ovr_flags & OVR_MM1 || ovr_flags & OVR_MM2) {
+					if (ovr_flags & OVR_MM1) { src_loc = 1; }
+					else { src_loc = 2; }
+				}
+				else { 	/* Assign primary/standby events to physical MM */
+					struct snmp_value value;
+					int primary, standby;
+
+					err = snmp_bc_snmp_get(custom_handle, SNMP_BC_MGMNT_ACTIVE, &value, SAHPI_TRUE);
+					if (err) {
+						dbg("Cannot get OID=%s.",  SNMP_BC_MGMNT_ACTIVE);
+						return(SA_ERR_HPI_INTERNAL_ERROR);
+					}
+
+					primary = value.integer;
+					if (value.integer == 1) { standby = 2; }
+					else { standby = 1; }
+					
+					if (ovr_flags & OVR_MM_PRIME) { src_loc = primary; }
+					else { src_loc = standby; } /* Standby override */
+				}
 			}
-			
 			entity_type = snmp_bc_rpt_array[rpt_index].rpt.ResourceEntity.Entry[0].EntityType;
-			
 		}
 		else {
 			rpt_index = BC_RPT_ENTRY_CHASSIS;
@@ -1373,23 +1462,33 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 		dbg("Cannot concat Entity Path. Error=%s.", oh_lookup_error(err));
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
-	err = oh_set_ep_location(&ep, entity_type, loc);
+	/* FIXME:: Need to rewrite this section when discover multiple BEMs/blade */
+	/* Also switches aren't currently supported with the Source field - can remove this logic */
+	if ((isexpansioncard == SAHPI_TRUE)) {
+		err = oh_set_ep_location(&ep, entity_type, 1);
+	}
+	else {
+		err = oh_set_ep_location(&ep, entity_type, src_loc);
+	}
+
 	if (err) {
 		dbg("Cannot set location. Type=%s; Location=%d; Error=%s.",
-		    oh_lookup_entitytype(entity_type), loc, oh_lookup_error(err));
+		    oh_lookup_entitytype(entity_type), src_loc, oh_lookup_error(err));
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 
 	if ((isblade == SAHPI_TRUE) || (isexpansioncard == SAHPI_TRUE)) {
-		err = oh_set_ep_location(&ep, SAHPI_ENT_PHYSICAL_SLOT, loc);	
+		err = oh_set_ep_location(&ep, SAHPI_ENT_PHYSICAL_SLOT, src_loc);	
+	} else if (ismm == SAHPI_TRUE) {
+		err = oh_set_ep_location(&ep, BLADECENTER_SYS_MGMNT_MODULE_SLOT, src_loc);	
 	}
 	
 	/* Special case - if Expansion Card set location of parent blade as well */
 	if (isexpansioncard == SAHPI_TRUE) {
-		err = oh_set_ep_location(&ep, SAHPI_ENT_SBC_BLADE, loc);
+		err = oh_set_ep_location(&ep, SAHPI_ENT_SBC_BLADE, src_loc);
 		if (err) {
 			dbg("Cannot set location. Type=%s; Location=%d; Error=%s.",
-			    oh_lookup_entitytype(SAHPI_ENT_SBC_BLADE), loc, oh_lookup_error(err));  
+			    oh_lookup_entitytype(SAHPI_ENT_SBC_BLADE), src_loc, oh_lookup_error(err));  
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
 	}
@@ -1408,10 +1507,6 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
          * number to an unique entity path. User app needs to worry about if resource 
          * is actually in the chassis - just as they do for hot swapped resources.
          **********************************************************************************/
-	
-	/* FIXME:: SES Is this required anymore? - should always get a valid RID if Peter discovers
-           all possible values. Can't find a RID implies and error */
-
 	if (logsrc2res->rid == 0) {
 		logsrc2res->rid = oh_uid_from_entity_path(&ep);
 		if (logsrc2res->rid == 0) {
@@ -1437,30 +1532,45 @@ static SaErrorT snmp_bc_logsrc2rid(struct oh_handler_state *handle,
 SaErrorT snmp_bc_add_to_eventq(struct oh_handler_state *handle, SaHpiEventT *thisEvent, SaHpiBoolT prepend)
 {
 	SaHpiEntryIdT rdrid;
-        struct oh_event working;
         struct oh_event *e = NULL;
 	SaHpiRptEntryT *thisRpt;
 	SaHpiRdrT      *thisRdr;
-	
-	rdrid = 0;
-        memset(&working, 0, sizeof(struct oh_event));
+	LogSource2ResourceT logsrc2res;
+	SaErrorT err;
+        struct snmp_bc_hnd *custom_handle = (struct snmp_bc_hnd *)handle->data;
 
-	working.did = oh_get_default_domain_id();
-	working.type = OH_ET_HPI;
-	
+        /* Insert entry to eventq for processing */
+        e = snmp_bc_alloc_oh_event();
+        if (!e) {
+                dbg("Out of memory.");
+                return(SA_ERR_HPI_OUT_OF_SPACE);
+        }
+				
 	thisRpt = oh_get_resource_by_id(handle->rptcache, thisEvent->Source);
-        if (thisRpt) working.u.hpi_event.res = *thisRpt;
-	else dbg("NULL Rpt pointer for rid %d\n", thisEvent->Source);
-        memcpy(&working.u.hpi_event.event, thisEvent, sizeof(SaHpiEventT));
+        if (thisRpt) e->resource = *thisRpt;
+        memcpy(&e->event, thisEvent, sizeof(SaHpiEventT));
 
 	/* Setting RDR ID to event struct */	
 	switch (thisEvent->EventType) {
-	case SAHPI_ET_OEM:
 	case SAHPI_ET_HOTSWAP:
+		if (snmp_bc_isrediscover(thisEvent) == SNMP_BC_RESOURCE_INSTALLED) {
+    			for (thisRdr = oh_get_rdr_by_id(handle->rptcache, thisEvent->Source, SAHPI_FIRST_ENTRY);
+                     	     thisRdr != NULL;
+                             thisRdr = oh_get_rdr_next(handle->rptcache, thisEvent->Source, thisRdr->RecordId)) 
+			{
+				e->rdrs = g_slist_append(e->rdrs, g_memdup(thisRdr, sizeof(SaHpiRdrT)));
+
+                	}
+		} else if (snmp_bc_isrediscover(thisEvent) == SNMP_BC_RESOURCE_REMOVED) {
+			/* Call rediscovery to remove rpt and rdrs from rptcache */
+			if (thisRpt) logsrc2res.ep = thisRpt->ResourceEntity;
+			err = snmp_bc_rediscover(handle, thisEvent, &logsrc2res);
+		}
+		break;
+	case SAHPI_ET_OEM:
 	case SAHPI_ET_USER:
 		/* There is no RDR associated to OEM event */
-		memset(&working.u.hpi_event.rdr, 0, sizeof(SaHpiRdrT));
-		working.u.hpi_event.rdr.RdrType = SAHPI_NO_RECORD;
+		e->rdrs = NULL;
 		/* Set RDR Type to SAHPI_NO_RECORD, spec B-01.01 */
 		/* It is redundant because SAHPI_NO_RECORD == 0, Put code here for clarity */
 		break;			           
@@ -1469,7 +1579,7 @@ SaErrorT snmp_bc_add_to_eventq(struct oh_handler_state *handle, SaHpiEventT *thi
 				    thisEvent->EventDataUnion.SensorEvent.SensorNum);
 		thisRdr =  oh_get_rdr_by_id(handle->rptcache, thisEvent->Source, rdrid);
 		if (thisRdr) 
-			working.u.hpi_event.rdr = *thisRdr;
+			e->rdrs = g_slist_append(e->rdrs, g_memdup(thisRdr, sizeof(SaHpiRdrT)));
 		else 
 			dbg("Rdr not found for rid %d, rdrid %d\n",thisEvent->Source, rdrid);
 		break;
@@ -1478,7 +1588,7 @@ SaErrorT snmp_bc_add_to_eventq(struct oh_handler_state *handle, SaHpiEventT *thi
 				    thisEvent->EventDataUnion.WatchdogEvent.WatchdogNum);
 		thisRdr =  oh_get_rdr_by_id(handle->rptcache, thisEvent->Source, rdrid);
 		if (thisRdr) 
-			working.u.hpi_event.rdr = *thisRdr;
+			e->rdrs = g_slist_append(e->rdrs, g_memdup(thisRdr, sizeof(SaHpiRdrT)));
 		else 
 			dbg("Rdr not found for rid %d, rdrid %d\n",thisEvent->Source, rdrid);
 
@@ -1493,18 +1603,11 @@ SaErrorT snmp_bc_add_to_eventq(struct oh_handler_state *handle, SaHpiEventT *thi
 		break;
 	} 
 	
-        /* Insert entry to eventq for processing */
-        e = g_malloc0(sizeof(struct oh_event));
-        if (!e) {
-                dbg("Out of memory.");
-                return(SA_ERR_HPI_OUT_OF_SPACE);
-        }
-        memcpy(e, &working, sizeof(struct oh_event));
 
 	if (prepend == SAHPI_TRUE) { 
-       		handle->eventq = g_slist_prepend(handle->eventq, e);
+       		custom_handle->eventq = g_slist_prepend(custom_handle->eventq, e);
 	} else {
-		handle->eventq = g_slist_append(handle->eventq, e);
+		custom_handle->eventq = g_slist_append(custom_handle->eventq, e);
 	}
 	
         return(SA_OK);
