@@ -38,7 +38,9 @@ do { \
  * Plugin handle - normal operation.
  * NULL - on error.
  **/
-void *snmp_bc_open(GHashTable *handler_config)
+void *snmp_bc_open(GHashTable *handler_config,
+                   unsigned int hid,
+                   oh_evt_queue *eventq)
 {
         struct oh_handler_state *handle;
         struct snmp_bc_hnd *custom_handle;
@@ -51,7 +53,13 @@ void *snmp_bc_open(GHashTable *handler_config)
 	if (!handler_config) {
                 dbg("INVALID PARM - NULL handler_config pointer.");
                 return NULL;	
-	}
+	} else if (!hid) {
+                dbg("Bad handler id passed.");
+                return NULL;
+        } else if (!eventq) {
+                dbg("No event queue was passed.");
+                return NULL;
+        }
 
         root_tuple = (char *)g_hash_table_lookup(handler_config, "entity_root");
         if (!root_tuple) {
@@ -74,6 +82,8 @@ void *snmp_bc_open(GHashTable *handler_config)
 
         handle->data = custom_handle;
         handle->config = handler_config;
+        handle->hid = hid;
+        handle->eventq = eventq;
 
         /* Initialize the lock */
         /* g_static_rec_mutex_init(&handle->handler_lock); */
@@ -82,19 +92,31 @@ void *snmp_bc_open(GHashTable *handler_config)
 	
         /* Initialize resource masks */
 	/* Set all masks and counts to zero's    */
-	custom_handle->max_pb_supported = 0;		/* pb - processor blade */
-	custom_handle->max_blower_supported = 0;	/* blower - blower  */
-	custom_handle->max_pm_supported = 0;		/* pm - power module    */
-	custom_handle->max_sm_supported = 0;		/* sm - switch module   */
+	custom_handle->max_pb_supported = 0;		/* pb - processor blade   */
+	custom_handle->max_blower_supported = 0;	/* blower - blower        */
+	custom_handle->max_pm_supported = 0;		/* pm - power module      */
+	custom_handle->max_sm_supported = 0;		/* sm - switch module     */
 	custom_handle->max_mm_supported = 0;		/* mm - management module */
 	custom_handle->max_mt_supported = 0;		/* mt - media tray        */
+	custom_handle->max_filter_supported = 0;	/* filter - front bezel   */
+	custom_handle->max_tap_supported = 0;		/* tap-telco alarm panel  */
+	custom_handle->max_nc_supported = 0;		/* nc - network clock card*/
+	custom_handle->max_mx_supported = 0;		/* mx - multiplex card    */
+	custom_handle->max_mmi_supported = 0;		/* mmi- mm interposer     */	
+	custom_handle->max_smi_supported = 0;		/* smi- switch interposer */
 	
 	memset(&custom_handle->installed_pb_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
 	memset(&custom_handle->installed_blower_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
 	memset(&custom_handle->installed_pm_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
 	memset(&custom_handle->installed_sm_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
 	memset(&custom_handle->installed_mm_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
+	memset(&custom_handle->installed_tap_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
+	memset(&custom_handle->installed_nc_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
+	memset(&custom_handle->installed_mx_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);	
+	memset(&custom_handle->installed_mmi_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);	
+	memset(&custom_handle->installed_smi_mask, '\0', SNMP_BC_MAX_RESOURCES_MASK);
 	custom_handle->installed_mt_mask = 0;
+	custom_handle->installed_filter_mask = 0;
 
         /* Indicate this is the 1st discovery (T0 discovery) */
         /* Use to see if we need to create events for log entries.  */
@@ -286,9 +308,11 @@ void *snmp_bc_open(GHashTable *handler_config)
 				err = snmp_bc_snmp_get(custom_handle, SNMP_BC_CHASSIS_SUBTYPE_OID, &get_value, SAHPI_FALSE);
 				if (err) {
 					dbg("Cannot read model subtype");
-					return NULL;
+					chassis_subtype = SNMP_BC_CHASSIS_SUBTYPE_ORIG;
+				} else {
+					chassis_subtype = get_value.integer;
 				}
-				chassis_subtype = get_value.integer;
+				
 
 				if (chassis_type == SNMP_BC_CHASSIS_TYPE_BC &&
 				    chassis_subtype == SNMP_BC_CHASSIS_SUBTYPE_ORIG) {
@@ -311,6 +335,14 @@ void *snmp_bc_open(GHashTable *handler_config)
 					break;
 				}
 
+								
+				if (chassis_type == SNMP_BC_CHASSIS_TYPE_BCT &&
+				    chassis_subtype == SNMP_BC_CHASSIS_SUBTYPE_H) {
+					trace("Found BCHT");
+					custom_handle->platform = SNMP_BC_PLATFORM_BCHT;
+					break;
+				}
+				
 				dbg("Unknown BladeCenter model");
 				return NULL;
 			}
@@ -347,7 +379,7 @@ void *snmp_bc_open(GHashTable *handler_config)
 
 		err = snmp_bc_snmp_get(custom_handle, oid, &get_value, SAHPI_TRUE);
 		if (err == SA_OK) {
-			strcpy(custom_handle->handler_timezone, get_value.string);
+			strncpy(custom_handle->handler_timezone, get_value.string,9);
 		}
 		else {
 			dbg("Cannot read DST=%s; Error=%d.", oid, get_value.type);
@@ -424,5 +456,6 @@ void snmp_bc_close(void *hnd)
 	
 }
 
-void * oh_open (GHashTable *) __attribute__ ((weak, alias("snmp_bc_open")));
+void * oh_open (GHashTable *, unsigned int, oh_evt_queue *) __attribute__ ((weak, alias("snmp_bc_open")));
 void * oh_close (void *) __attribute__ ((weak, alias("snmp_bc_close")));
+
