@@ -307,9 +307,9 @@ int oh_load_plugin(char *plugin_name)
         plugin = oh_get_plugin(plugin_name);
         if (plugin) {
                 oh_release_plugin(plugin);
-                dbg("Warning. Plugin %s already loaded. Not loading twice.",
-                    plugin_name);
-                return -1;
+                trace("Plugin %s already loaded. Not loading twice.",
+                      plugin_name);
+                return 0;
         }
 
         plugin = (struct oh_plugin *)g_malloc0(sizeof(struct oh_plugin));
@@ -423,7 +423,6 @@ static void __dec_handler_refcount(struct oh_handler *h)
 
 static void __delete_handler(struct oh_handler *h)
 {
-        GSList *node = NULL;
         struct oh_plugin *plugin = NULL;
 
         if (!h) return;
@@ -439,10 +438,6 @@ static void __delete_handler(struct oh_handler *h)
 
         /* Free the oh_handler members first, then the handler. */
         /* FIXME: Where/When should the handler config table be freed? */
-        for (node = h->dids; node; node = node->next) {
-                g_free(node->data);
-        }
-        g_slist_free(h->dids);
         g_static_rec_mutex_free(&h->lock);
         g_static_rec_mutex_free(&h->refcount_lock);
         g_free(h);
@@ -546,41 +541,41 @@ static struct oh_handler *new_handler(GHashTable *handler_config)
 {       /* Return a new oh_handler instance */
         struct oh_plugin *plugin = NULL;
         struct oh_handler *handler = NULL;
+	char *plugin_name = NULL;
         static unsigned int handler_id = 1;
         unsigned int *hidp;
-        char *hid_strp;
 
         if (!handler_config) {
                 dbg("ERROR creating new handler. Invalid parameter.");
                 return NULL;
         }
 
+	plugin_name = (char *)g_hash_table_lookup(handler_config, "plugin");
+	if (!plugin_name) {
+		dbg("ERROR creating new handler. No plugin name received.");
+		return NULL;
+	}
+
         handler = (struct oh_handler *)g_malloc0(sizeof(struct oh_handler));
-        if (!handler) {
-                dbg("Out of Memory!");
-                return NULL;
+        hidp = (unsigned int *)g_malloc0(sizeof(unsigned int));
+
+        plugin = oh_get_plugin(plugin_name);
+        if(!plugin) { /* Attempt to load plugin here once */
+		int rc = oh_load_plugin(plugin_name);
+		if (rc) {
+                	dbg("Could not create handler. Plugin %s not loaded",
+                    	    plugin_name);
+                	goto cleanexit;
+		}
+
+		plugin = oh_get_plugin(plugin_name);
+		if (!plugin) {
+			dbg("Tried but could not get a plugin to "
+			    "create this handler.");
+			goto cleanexit;
+		}
         }
 
-        hidp = (unsigned int *)g_malloc(sizeof(unsigned int));
-        if (!hidp) {
-                dbg("Out of Memory!");
-                g_free(handler);
-                return NULL;
-        }
-        hid_strp = strdup("handler-id");
-        if (!hid_strp) {
-                dbg("Out of Memory!");
-                g_free(handler);
-                g_free(hidp);
-                return NULL;
-        }
-
-        plugin = oh_get_plugin((char *)g_hash_table_lookup(handler_config, "plugin"));
-        if(!plugin) {
-                dbg("Attempt to create handler for unknown plugin %s",
-                    (char *)g_hash_table_lookup(handler_config, "plugin"));
-                goto cleanexit;
-        }
         /* Initialize handler */
         handler->abi = plugin->abi;
         plugin->handler_count++; /* Increment # of handlers using the plugin */
@@ -589,10 +584,8 @@ static struct oh_handler *new_handler(GHashTable *handler_config)
         handler->id = handler_id++;
         g_static_rec_mutex_unlock(&oh_handlers.lock);
         *hidp = handler->id;
-        g_hash_table_insert(handler_config, (gpointer)hid_strp,(gpointer)hidp);
         handler->plugin_name = (char *)g_hash_table_lookup(handler_config, "plugin");
         handler->config = handler_config;
-        handler->dids = NULL;
         handler->refcount = 0;
         g_static_rec_mutex_init(&handler->lock);
         g_static_rec_mutex_init(&handler->refcount_lock);
@@ -600,7 +593,6 @@ static struct oh_handler *new_handler(GHashTable *handler_config)
         return handler;
 cleanexit:
         g_free(hidp);
-        g_free(hid_strp);
         g_free(handler);
         return NULL;
 }
@@ -609,45 +601,45 @@ cleanexit:
  * oh_create_handler
  * @handler_config: Hash table containing the configuration for a handler
  * read from the configuration file.
+ * @hid: pointer where hid of newly created handler will be stored.
  *
- * Returns: 0 on Failure, otherwise the handler id (id > 0) of
- * the newly created handler
+ * Returns: SA_OK on success. If handler failed to open, then @hid will
+ * contain a valid handler id, but SA_ERR_HPI_INTERNAL_ERROR will be
+ * returned.
  **/
-unsigned int oh_create_handler (GHashTable *handler_config)
+SaErrorT oh_create_handler (GHashTable *handler_config, unsigned int *hid)
 {
-        struct oh_handler *handler;
-        unsigned int new_hid = 0;
+        struct oh_handler *handler = NULL;
 
-        if (!handler_config) {
-                dbg("ERROR loading handler. Invalid handler configuration passed.");
-                return 0;
+        if (!handler_config || !hid) {
+                dbg("ERROR creating handler. Invalid parameters.");
+                return SA_ERR_HPI_INVALID_PARAMS;
         }
 
+	*hid = 0;
+
         handler = new_handler(handler_config);
-        if (handler == NULL) {
-                return 0;
-        }
+        if (!handler) return SA_ERR_HPI_ERROR;
 
-        new_hid = handler->id;
+        *hid = handler->id;
         g_static_rec_mutex_lock(&oh_handlers.lock);
         oh_handlers.list = g_slist_append(oh_handlers.list, handler);
         g_hash_table_insert(oh_handlers.table,
                             &(handler->id),
                             g_slist_last(oh_handlers.list));
 
-        handler->hnd = handler->abi->open(handler->config);
+        handler->hnd = handler->abi->open(handler->config,
+                                          handler->id,
+                                          &oh_process_q);
         if (!handler->hnd) {
-                g_hash_table_remove(oh_handlers.table, &handler->id);
-                oh_handlers.list = g_slist_remove(oh_handlers.list, &(handler->id));
-                g_static_rec_mutex_unlock(&oh_handlers.lock);
                 dbg("A handler #%d on the %s plugin could not be opened.",
                     handler->id, handler->plugin_name);
-                __delete_handler(handler);
-                return 0;
+		g_static_rec_mutex_unlock(&oh_handlers.lock);
+		return SA_ERR_HPI_INTERNAL_ERROR;
         }
         g_static_rec_mutex_unlock(&oh_handlers.lock);
 
-        return new_hid;
+        return SA_OK;
 }
 
 /**
@@ -688,162 +680,36 @@ int oh_destroy_handler(unsigned int hid)
         return 0;
 }
 
-
 /**
- * oh_domain_served_by_handler
- * @hid: A handler id.
- * @did: A domain id.
+ * oh_discover_resources
  *
- * Checks to see whether @did is a valid domain for @hid.
- * The default domain is always a valid domain for any handler.
- *
- * Returns: FALSE on a failed check, otherwise TRUE.
+ * Returns: SA_OK on success.
  **/
-int oh_domain_served_by_handler(unsigned int hid, SaHpiDomainIdT did)
-{
-        GSList *node = NULL;
-        struct oh_handler *h = NULL;
-
-        if (hid < 1 || did < 1) {
-                dbg("Warning - Invalid parameters passed");
-                return 0;
-        }
-
-        if (did == oh_get_default_domain_id())
-                return 1;
-
-        h = oh_get_handler(hid);
-        if (h == NULL) return 0;
-
-        for (node = h->dids; node; node = node->next) {
-                SaHpiDomainIdT cur_did = *((SaHpiDomainIdT *)node->data);
-                if (cur_did == did) {
-                        oh_release_handler(h);
-                        return 1;
-                }
-        }
-        oh_release_handler(h);
-
-        return 0;
-}
-
-/**
- * oh_add_domain_to_handler
- * @hid: A handler id.
- * @did: A domain id.
- *
- * Adds a domain to a handler, indicating that the handler
- * can serve events/resources in said domain.
- *
- * Returns: 0 on success, otherwise an error ocurred.
- **/
-int oh_add_domain_to_handler(unsigned int hid, SaHpiDomainIdT did)
-{
-        struct oh_handler *h;
-
-        if (hid < 1 || did < 1) {
-                dbg("Warning - Invalid parameters passed");
-                return -1;
-        }
-
-        h = oh_get_handler(hid);
-        if (h == NULL) {
-                return -2;
-        }
-
-        h->dids = g_slist_append(h->dids,
-                                 g_memdup(&did, sizeof(SaHpiDomainIdT)));
-        oh_release_handler(h);
-
-        return 0;
-}
-
-/**
- * oh_remove_domain_from_handler
- * @hid: A handler id.
- * @did: A domain id.
- *
- * Removes a domain from a handler, indicating that the handler
- * cannot serve events/resources in that domain.
- *
- * Returns: 0 on success, otherwise an error ocurred.
- **/
-int oh_remove_domain_from_handler(unsigned int hid, SaHpiDomainIdT did)
-{
-        struct oh_handler *h;
-        GSList *node = NULL;
-
-        if (hid < 1) return -1; /* Invalid handler id */
-        if (did < 1) return -2; /* Invalid domain id */
-        /* Cannot remove default domain from handler */
-        if (did == oh_get_default_domain_id()) return -3;
-
-
-        h = oh_get_handler(hid);
-        if (h == NULL) {
-                return -4; /* Handler not found */
-        }
-
-        for (node = h->dids; node; node = node->next) {
-                SaHpiDomainIdT cur_did = *((SaHpiDomainIdT *)node->data);
-                if (did == cur_did) {
-                        g_free(node->data);
-                        h->dids = g_slist_delete_link(h->dids, node);
-                        oh_release_handler(h);
-                        return 0;
-                }
-        }
-        oh_release_handler(h);
-
-        return -5; /* Domain id not found in the handler */
-}
-
-/**
- * oh_domain_resource_discovery
- * @did: A domain ID.
- *
- * @did of 0 means perform discovery on all domains. Otherwise,
- * will only perform discovery in domain specified. This call will
- * undestand SAHPI_UNSPECIFIED_DOMAIN_ID as the default domain.
- *
- * Returns: SA_ERR_HPI_ERROR if all handlers return error on discovery.
- * Success (SA_OK) if at least one handler returned SA_OK on discovery.
- **/
-SaErrorT oh_domain_resource_discovery(SaHpiDomainIdT did)
+SaErrorT oh_discovery(void)
 {
         unsigned int hid = 0, next_hid;
         struct oh_handler *h = NULL;
         SaErrorT error = SA_ERR_HPI_ERROR;
 
-        if (did == SAHPI_UNSPECIFIED_DOMAIN_ID)
-                did = oh_get_default_domain_id();
-
         oh_getnext_handler_id(hid, &next_hid);
         while (next_hid) {
                 hid = next_hid;
 
-                if (did == 0 || oh_domain_served_by_handler(hid, did)) {
-                        SaErrorT cur_error;
+                SaErrorT cur_error;
 
-                        h = oh_get_handler(hid);
-                        if (!h) {
-                                dbg("No such handler %d", hid);
-                                break;
-                        }
-
-                        if (h->abi->discover_domain_resources != NULL && did != 0) {
-                                cur_error = h->abi->discover_domain_resources(h->hnd, did);
-                                if (cur_error == SA_OK && error) {
-                                        error = cur_error;
-                                }
-                        } else if (h->abi->discover_resources != NULL) {
-                                cur_error = h->abi->discover_resources(h->hnd);
-                                if (cur_error == SA_OK && error) {
-                                        error = cur_error;
-                                }
-                        }
-                        oh_release_handler(h);
+                h = oh_get_handler(hid);
+                if (!h) {
+                        dbg("No such handler %d", hid);
+                        break;
                 }
+
+                if (h->abi->discover_resources != NULL) {
+                        cur_error = h->abi->discover_resources(h->hnd);
+                        if (cur_error == SA_OK && error) {
+                                error = cur_error;
+                        }
+                }
+                oh_release_handler(h);
                 oh_getnext_handler_id(hid, &next_hid);
         }
 
@@ -879,8 +745,6 @@ int oh_load_plugin_functions(struct oh_plugin *plugin, struct oh_abi_v2 **abi)
                                                 "oh_get_event");
         (*abi)->discover_resources        = lt_dlsym(plugin->dl_handle,
                                                 "oh_discover_resources");
-        (*abi)->discover_domain_resources = lt_dlsym(plugin->dl_handle,
-                                                "oh_discover_domain_resource");
         (*abi)->set_resource_tag          = lt_dlsym(plugin->dl_handle,
                                                 "oh_set_resource_tag");
         (*abi)->set_resource_severity     = lt_dlsym(plugin->dl_handle,
@@ -967,6 +831,10 @@ int oh_load_plugin_functions(struct oh_plugin *plugin, struct oh_abi_v2 **abi)
                                                 "oh_set_hotswap_state");
         (*abi)->request_hotswap_action    = lt_dlsym(plugin->dl_handle,
                                                 "oh_request_hotswap_action");
+	(*abi)->get_autoextract_timeout   = lt_dlsym(plugin->dl_handle,
+                                                "oh_get_autoextract_timeout");
+	(*abi)->set_autoextract_timeout   = lt_dlsym(plugin->dl_handle,
+                                                "oh_set_autoextract_timeout");
         (*abi)->get_power_state           = lt_dlsym(plugin->dl_handle,
                                                 "oh_get_power_state");
         (*abi)->set_power_state           = lt_dlsym(plugin->dl_handle,
@@ -981,6 +849,8 @@ int oh_load_plugin_functions(struct oh_plugin *plugin, struct oh_abi_v2 **abi)
                                                 "oh_get_reset_state");
         (*abi)->set_reset_state           = lt_dlsym(plugin->dl_handle,
                                                 "oh_set_reset_state");
+        (*abi)->inject_event            = lt_dlsym(plugin->dl_handle,
+                                                   "oh_inject_event");
 
         return 0;
 
