@@ -18,7 +18,7 @@
 #include <oHpi.h>
 
 /**
- * Create handler for non-loaded plugin.
+ * Create handler for non-existant plugin.
  * Pass on error, otherwise test failed.
  **/
  
@@ -30,11 +30,11 @@ int main(int argc, char **argv)
         
         setenv("OPENHPI_CONF","./noconfig", 1);
         
-        if (saHpiSessionOpen(1, &sid, NULL))
+        if (saHpiSessionOpen(SAHPI_UNSPECIFIED_DOMAIN_ID, &sid, NULL))
                 return -1;
                                
         /* Set configuration. */
-        g_hash_table_insert(config, "plugin", "libsimulator");
+        g_hash_table_insert(config, "plugin", "libnoplugin");
         g_hash_table_insert(config, "entity_root", "{SYSTEM_CHASSIS,1}");
         g_hash_table_insert(config, "name", "test");
         g_hash_table_insert(config, "addr", "0");
