@@ -31,12 +31,9 @@ int main(int argc, char **argv)
         
         setenv("OPENHPI_CONF","./noconfig", 1);
         
-        if (saHpiSessionOpen(1, &sid, NULL))
+        if (saHpiSessionOpen(SAHPI_UNSPECIFIED_DOMAIN_ID, &sid, NULL))
                 return -1;
-                
-        if (oHpiPluginLoad("libsimulator"))
-                return -1;
-                
+
         /* Set configuration. */
         g_hash_table_insert(config, "plugin", "libsimulator");
         g_hash_table_insert(config, "entity_root", "{SYSTEM_CHASSIS,1}");
