@@ -39,10 +39,10 @@ int main(int argc, char **argv)
                 ep.Entry[0].EntityLocation = i;
                 id[i] = oh_uid_from_entity_path(&ep);
         }
-	
+
         for (i = 0; i < 10; i++) {
                 ep.Entry[0].EntityLocation = i;
-                if (oh_entity_path_lookup(id+i, &rep))
+                if (oh_entity_path_lookup(id[i], &rep))
                         return 1;
 
                 if (!oh_cmp_ep(&ep, &rep))
